@@ -136,10 +136,45 @@ DO CALL CleanupOldCpanelImports();
 -- GRANT SELECT, INSERT, UPDATE, DELETE ON whp.cpanel_imports TO 'whp_user'@'localhost';
 -- GRANT SELECT, INSERT, UPDATE, DELETE ON whp.cpanel_imported_* TO 'whp_user'@'localhost';
 
--- Add indexes for better performance
-ALTER TABLE cpanel_imports ADD INDEX idx_username_status (username, status);
-ALTER TABLE cpanel_imported_domains ADD INDEX idx_domain_type (domain_type);
-ALTER TABLE cpanel_imported_databases ADD INDEX idx_import_status (import_status);
+-- Add indexes for better performance (with safe existence checking)
+DELIMITER //
+CREATE PROCEDURE IF NOT EXISTS AddCpanelImportIndexesSafe()
+BEGIN
+    -- Add compound index for username + status if it doesn't exist
+    IF NOT EXISTS (
+        SELECT 1 FROM INFORMATION_SCHEMA.STATISTICS 
+        WHERE table_schema = DATABASE() 
+        AND table_name = 'cpanel_imports' 
+        AND index_name = 'idx_username_status'
+    ) THEN
+        ALTER TABLE cpanel_imports ADD INDEX idx_username_status (username, status);
+    END IF;
+    
+    -- Add domain_type index if it doesn't exist
+    IF NOT EXISTS (
+        SELECT 1 FROM INFORMATION_SCHEMA.STATISTICS 
+        WHERE table_schema = DATABASE() 
+        AND table_name = 'cpanel_imported_domains' 
+        AND index_name = 'idx_domain_type'
+    ) THEN
+        ALTER TABLE cpanel_imported_domains ADD INDEX idx_domain_type (domain_type);
+    END IF;
+    
+    -- Add import_status index if it doesn't exist
+    IF NOT EXISTS (
+        SELECT 1 FROM INFORMATION_SCHEMA.STATISTICS 
+        WHERE table_schema = DATABASE() 
+        AND table_name = 'cpanel_imported_databases' 
+        AND index_name = 'idx_import_status'
+    ) THEN
+        ALTER TABLE cpanel_imported_databases ADD INDEX idx_import_status (import_status);
+    END IF;
+END//
+DELIMITER ;
+
+-- Execute the procedure and then drop it
+CALL AddCpanelImportIndexesSafe();
+DROP PROCEDURE AddCpanelImportIndexesSafe;
 
 -- Note: cPanel import functionality tables created successfully
 -- (Removed system_logs insert as table may not exist on all installations)
\ No newline at end of file
